==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Arc/Arc2PR/ts/Arc2PR_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>Arc2PR</name>
    <message>
        <location filename="../Arc2PR.js" line="+67"/>
        <source>Start point</source>
        <translation>Začetna točka</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>End point</source>
        <translation>Končna točka</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Invalid radius</source>
        <translation>Neveljaven radij</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>The two points are identical</source>
        <translation>Vneseni točki sta identični</translation>
    </message>
    <message>
        <location filename="../Arc2PR.ui" line="+17"/>
        <source>Radius:</source>
        <translation>Radij:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Direction:</source>
        <translation>Smer:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Counter Clockwise (Positive)</source>
        <translation>Nasproti urinega kazalca (Pozitivna)</translation>
    </message>
    <message>
        <location line="+13"/>
        <location line="+17"/>
        <source>Direction</source>
        <translation>Smer</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Clockwise (Negative)</source>
        <translation>V smeri urinega kazalca (Negativna)</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Solution:</source>
        <translation>Rešitev:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Shorter Arc</source>
        <translation>Krajši lok</translation>
    </message>
    <message>
        <location line="+13"/>
        <location line="+17"/>
        <source>Solution</source>
        <translation>Rešitev</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Longer Arc</source>
        <translation>Daljši lok</translation>
    </message>
    <message>
        <location filename="../Arc2PRInit.js" line="+2"/>
        <source>&amp;2 Points and Radius</source>
        <translation>&amp;2 točki in radij</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc from 2 points and radius</source>
        <translation>Nariši lok iz dveh točk in radiusa</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Arc/Arc2PR/ts/Arc2PR_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>Arc2PR</name>
    <message>
        <location filename="../Arc2PR.js" line="+67"/>
        <source>Start point</source>
        <translation>Začetna točka</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>End point</source>
        <translation>Končna točka</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Invalid radius</source>
        <translation>Neveljaven polmer</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>The two points are identical</source>
        <translation>Vneseni točki sta identični</translation>
    </message>
    <message>
        <location filename="../Arc2PR.ui" line="+17"/>
        <source>Radius:</source>
        <translation>Polmer:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Direction:</source>
        <translation>Smer:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Counter Clockwise (Positive)</source>
        <translation>Nasproti urinega kazalca (Pozitivna)</translation>
    </message>
    <message>
        <location line="+13"/>
        <location line="+17"/>
        <source>Direction</source>
        <translation>Smer</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Clockwise (Negative)</source>
        <translation>V smeri urinega kazalca (Negativna)</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Solution:</source>
        <translation>Rešitev:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Shorter Arc</source>
        <translation>Krajši lok</translation>
    </message>
    <message>
        <location line="+13"/>
        <location line="+17"/>
        <source>Solution</source>
        <translation>Rešitev</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Longer Arc</source>
        <translation>Daljši lok</translation>
    </message>
    <message>
        <location filename="../Arc2PRInit.js" line="+2"/>
        <source>&amp;2 Points and Radius</source>
        <translation>&amp;2 točki in polmer</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc from 2 points and radius</source>
        <translation>Nariši lok iz dveh točk in polmera</translation>
    </message>
</context>
</TS>
